@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from django.contrib.auth import get_user_model
 from rest_framework import response, serializers, views, viewsets
-from rest_framework.decorators import api_view, detail_route, list_route
+from rest_framework.decorators import api_view, action
 
 
 class SimpleSerializer(serializers.Serializer):
@@ -10,6 +10,7 @@ class SimpleSerializer(serializers.Serializer):
 
 class BasicView(views.APIView):
     queryset = get_user_model().objects.none()
+
     def get(self, request, *args, **kwargs):
         return response.Response({'method': 'GET'})
 
@@ -26,7 +27,7 @@ class SimpleViewSet(viewsets.GenericViewSet):
     queryset = get_user_model().objects.none()
     serializer_class = SimpleSerializer
 
-    @list_route(methods=["patch", "put"])
+    @action(methods=["patch", "put"], detail=False)
     def patch_put(self, request):
         return response.Response({'method': request.method})
 
@@ -35,10 +36,10 @@ class SimpleModelViewSet(viewsets.ModelViewSet):
     queryset = get_user_model().objects.none()
     serializer_class = SimpleSerializer
 
-    @list_route(methods=["delete", "get"])
+    @action(methods=["delete", "get"], detail=False)
     def some_method(self, request):
         return response.Response({'method': request.method})
 
-    @detail_route(methods=["get", "post", "patch", "put"])
+    @action(methods=["get", "post", "patch", "put"], detail=True)
     def some_detail_metod(self, request):
         return response.Response({'method': request.method})
